@@ -15,6 +15,13 @@ class CartItem(object):
     def __repr__(self):
         return u'CartItem Object (%s)' % self.product
 
+    def to_dict(self):
+        return {
+            'product_pk': self.product.pk,
+            'quantity': self.quantity,
+            'price': self.price,
+        }
+
     @property
     def subtotal(self):
         """
@@ -126,6 +133,13 @@ class Cart(object):
         """
         return self._items_dict.values()
 
+    @property
+    def items_serializable(self):
+        """
+        The list of items formatted for serialization.
+        """
+        return [item.to_dict() for item in self.items]
+
     @property
     def count(self):
         """
@@ -140,6 +154,10 @@ class Cart(object):
         """
         return len(self._items_dict)
 
+    @property
+    def is_empty(self):
+        return self.unique_count == 0
+
     @property
     def products(self):
         """
